import requests
import sys

def fetch_flatpack_toml_from_dir(directory_name):
    base_url = "https://raw.githubusercontent.com/romlingroup/flatpack-ai/main/warehouse"
    toml_url = f"{base_url}/{directory_name}/flatpack.toml"
    response = requests.get(toml_url)
    if response.status_code != 200:
        return None
    return response.text

def fetch_github_dirs():
    url = "https://api.github.com/repos/romlingroup/flatpack-ai/contents/warehouse"
    response = requests.get(url)
    if response.status_code != 200:
        return ["Error fetching data from GitHub"]
    data = response.json()
    directories = [item['name'] for item in data if item['type'] == 'dir']
    return sorted(directories)

def install():
    dirs = fetch_github_dirs()
    for directory in dirs:
        toml_content = fetch_flatpack_toml_from_dir(directory)
        if toml_content:
            print(f"Contents of flatpack.toml in {directory}:\n{toml_content}\n")
        else:
            print(f"No flatpack.toml found in {directory}.\n")

def list_directories():
    dirs = fetch_github_dirs()
    return "\n".join(dirs)

def main():
    if len(sys.argv) < 2:
        print("Usage: flatpack.ai <command>")
        print("Available commands: help, list, test, install")
        return

    command = sys.argv[1]
    if command == "help":
        print("[HELP]")
    elif command == "install":
        install()
    elif command == "list":
        print(list_directories())
    elif command == "test":
        print("[TEST]")
    else:
        print(f"Unknown command: {command}")

if __name__ == "__main__":
    main()
